import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'
// 公共路由
export const constantRoutes = [
  {
    path: '/redirect',
    component: Layout,
    hidden: true,
    children: [
      {
        path: '/redirect/:path(.*)',
        component: () => import('@/views/redirect/index')
      }
    ]
  },
  {
    path: '/login',
    component: () => import('@/views/login/index'),
    hidden: true
  },
  {
    path: '/auth-redirect',
    component: () => import('@/views/login/auth-redirect'),
    hidden: true
  },
  {
    path: '/404',
    component: () => import('@/views/error-page/404'),
    hidden: true
  },
  {
    path: '/401',
    component: () => import('@/views/error-page/401'),
    hidden: true
  },
  {
    path: '/',
    component: Layout,
    redirect: '/dashboard',
    children: [
      {
        path: 'dashboard',
        component: () => import('@/views/dashboard/index'),
        name: 'Dashboard',
        meta: { title: 'dashboard', icon: 'dashboard', affix: true }
      }
    ]
  },
  {
    path: '/data_mark/relationshipManage',
    component: Layout,
    redirect: '/dashboard',
    children: [
      {
        path: 'ERDetail/:id',
        component: () => import('@/views/data_mark/relationshipManage/ERDetail.vue'),
        name: 'ERDetail',
        hidden: true,
        meta: {
          title: '详情',
          icon: 'icon',
          noCache: true,
          activeMenu: '/dataMark/relationshipManage'
        }
      }
    ]
  },
  {
    path: '/data_mark/datasetManage',
    component: Layout,
    redirect: '/dashboard',
    children: [
      {
        path: 'datasetDetail/:id',
        component: () => import('@/views/data_mark/dataManage/datasetDetail.vue'),
        name: 'datasetDetail',
        hidden: true,
        meta: {
          title: '数据集详情',
          icon: 'icon',
          noCache: true,
          activeMenu: '/dataManage/datasetManage'
        }
      }
    ]
  },
  {
    path: '/data_mark',
    component: Layout,
    redirect: '/dashboard',
    children: [
      {
        path: 'dataMark',
        component: () => import('@/views/data_mark/dataMark/index'),
        name: 'dataMark',
        meta: { title: '数据标注', icon: 'el-icon-more', noCache: false }
      }
    ]
  },
  {
    path: '/data_mark/dataMark',
    component: Layout,
    redirect: '/dashboard',
    hidden: true,
    children: [
      {
        path: 'markPage/:dataset_id/:id?',
        component: () => import('@/views/data_mark/dataMark/markPage.vue'),
        name: 'markPage',
        meta: { title: '标注', icon: 'el-icon-more', noCache: false, activeMenu: '/data_mark/dataMark' }
      }
    ]
  }
]

// 需要动态判断的路由
export const asyncRoutes = []
const createRouter = () =>
  new Router({
    mode: 'history', // require service support
    scrollBehavior: () => ({ y: 0 }),
    routes: constantRoutes
  })

const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

export default router
